from __future__ import annotations
from AinaTheme.utils import custom_colors
from AinaTheme.aina_class import Aina

theme = Aina(
    primary_hue=custom_colors.primary,
    secondary_hue=custom_colors.secondary,
)